/**
 * Vue File Uploader 组件入口文件
 * 支持 Vue 2.x 和 Vue 3.x
 */

import { isVue2 } from 'vue-demi'
import type { App } from '@vue/runtime-core'
import FileUploader from './components/FileUploader.vue'
import type { FileUploaderProps, UploadFile, UploadStatus } from './types'

// 如果是 Vue 2 环境，确保已安装 composition-api
if (isVue2) {
  try {
    require('@vue/composition-api')
  } catch (e) {
    console.error('[vue-file-uploader] When using Vue 2, @vue/composition-api is required.')
  }
}

// 导出独立组件，用于局部注册
export { FileUploader }
export type { FileUploaderProps, UploadFile, UploadStatus }

/**
 * Vue 插件安装函数
 * 用于全局注册组件
 * @param app Vue 应用实例
 */
const install = (app: App): void => {
  app.component('FileUploader', FileUploader)
}

// 导出 Vue 插件
export default {
  install,
  FileUploader
}

// 导出类型定义，供 TypeScript 使用
export * from './types'

// 自动安装（用于 CDN 引入场景）
declare global {
  interface Window {
    Vue?: App
  }
}

if (typeof window !== 'undefined' && window.Vue) {
  install(window.Vue)
} 